Massively Parallel and Portable Genomic Sequence Analysis (Mappgene)
====================================================================
Mappgene is a genomic sequence analysis workflow designed for high-performance computing. It currently wraps V-pipe (https://github.com/cbg-ethz/V-pipe) and iVar (https://github.com/andersen-lab/ivar) with a collection of useful scripts for deployment in almost any Linux environment.

License
-------
Mappgene is distributed under the terms of the BSD-3 License.

LLNL-CODE-821512
